"use strict";
/**
 * @fileoverview Disallows duplicate names in template bindings
 * @author James Garbutt <htttps://github.com/43081j>
 */
const template_analyzer_1 = require("../template-analyzer");
//------------------------------------------------------------------------------
// Rule Definition
//------------------------------------------------------------------------------
const rule = {
    meta: {
        docs: {
            description: 'Disallows duplicate names in template bindings',
            category: 'Best Practices',
            url: 'https://github.com/43081j/eslint-plugin-lit/blob/master/docs/rules/no-duplicate-template-bindings.md'
        },
        messages: {
            duplicateBinding: 'Duplicate bindings are not allowed.'
        }
    },
    create(context) {
        // variables should be defined here
        //----------------------------------------------------------------------
        // Helpers
        //----------------------------------------------------------------------
        //----------------------------------------------------------------------
        // Public
        //----------------------------------------------------------------------
        return {
            'TaggedTemplateExpression': (node) => {
                if (node.type === 'TaggedTemplateExpression' &&
                    node.tag.type === 'Identifier' &&
                    node.tag.name === 'html') {
                    const analyzer = template_analyzer_1.TemplateAnalyzer.create(node);
                    const dupeErrors = analyzer.errors.filter((err) => err.code === 'duplicate-attribute');
                    for (const err of dupeErrors) {
                        const loc = analyzer.resolveLocation(err);
                        if (loc) {
                            context.report({
                                loc: loc,
                                messageId: 'duplicateBinding'
                            });
                        }
                    }
                }
            }
        };
    }
};
module.exports = rule;
